# Predicate DSL API Reference

::: tsunami.predicate
    options:
      members:
        - Expr
        - Signal
        - Const
        - And
        - Or
        - Not
        - Xor
        - Eq
        - Gt
        - Lt
        - Rise
        - Fall
        - BitSlice
        - Sequence
        - PrecededBy
        - scope
        - signals
        - ScopeProxy
        - SignalsProxy
